#!/bin/bash -e
# This script contains the guest-side initialization procedure
# of a vserver guest. Hostname and /etc/hosts are initialized
# before startup, otherwise the first startup might produce strange
# errors related to the old hostname or network configuration.
#
# Parameters:
# Files:

. ./Config.sh

_setup_scriptName="$(basename "${0#*-}")"


###############################################################################
# Setup the locale and append it to the config file, so that all
# remaining setup scripts will use it immediately.

locale-gen en_US.UTF-8
export LANG=en_US.utf8
update-locale LANG=en_US.utf8
echo "export LANG=en_US.utf8" >> ./Config.sh


###############################################################################
# Fix some scripts that give unnecessary warnin/error messages when
# run within vserver. If one of these fixes is found out to be ubuntu
# distibution dependent, it should be moved to own setup script for
# that template version.

sed -i -r -e $'s/^([ \\t]+)if ifdown /\\1if true; then # if ifdown /' /etc/init.d/networking
# Replace problematic binaries, remove first to handle sysmlinks gracefully
rm -- /bin/mount; cp -a /bin/true /bin/mount
test -e /etc/init.d/udev && rm -- /etc/init.d/udev && cp -a /bin/true /etc/init.d/udev

# Remove upstart configurations, that might be problematic
for _setup_confFile in plymouth.conf udev.conf udev-fallback-graphics.conf udev-finish.conf udevmonitor.conf udevtrigger.conf upstart-udev-bridge.conf; do
  _setup_confPathName="/etc/init/${_setup_confFile}"
  if test -e "${_setup_confPathName}"; then
    rm -- "${_setup_confPathName}"
  fi
done
# Currently reloading does not work as expected: upstart still knows
# about udev jobs after deletion and reload. To avoid hangs during
# udev upgrade, set udev at hold.
initctl reload-configuration
echo "udev hold" | dpkg --set-selections
